# PyBacmman
- Helper functions to manipulate data generated by [BACMMAN software](https://github.com/jeanollion/bacmman) uder Pandas, see `pybacmman.pandas` module.
- Helper functions to save selection from pandas to BACMMAN: see `pybacmman.selections.saveAndOpenSelection()` method.
- Dataset class to facilitate handling of measurement tables and selections: see `pybacmman.dataset.Dataset` and `pybacmman.dataset.DatasetList` classes.

Here is [another python package](https://gitlab.com/MEKlab/pyberries) to handle bacmman data.
